#
# spec file for package ansible-documentation
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ansible-documentation
Version:        2.16.5
Release:        1.1
Summary:        Ansible community documentation and example files
License:        GPL-3.0-only
URL:            https://github.com/ansible/ansible-documentation
Source:         ansible-documentation-%{version}.tar.gz
BuildRequires:  ansible-core = %{version}
BuildRequires:  fdupes
Requires:       ansible-core = %{version}
BuildArch:      noarch

%description
User documentation and example files related to the Ansible package and Ansible core.

%prep
%autosetup -p1 -n ansible-documentation-%{version}

%build

%install
mkdir -p %{buildroot}%{_sysconfdir}/ansible/
cp examples/hosts %{buildroot}%{_sysconfdir}/ansible/
cp examples/ansible.cfg %{buildroot}%{_sysconfdir}/ansible/

%files
%doc README.md
%license COPYING
%config(noreplace) %{_sysconfdir}/ansible/ansible.cfg
%config(noreplace) %{_sysconfdir}/ansible/hosts

%changelog
* Wed Mar 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.5:
  * Merge pull request #1189 from ericzolf/ericzolf-fix-ipaddr
  * Unintended or undocumented functionality may be removed without
    deprecation (#1209) (#1223)
  * Document attributes (#1130) (#1230)
  * Cheat sheet instructions for ansible ad-hoc commands (#1171)
    (#1228)
  * Update playbooks_advanced_syntax.rst (#1208) (#1224)
  * Update testing_units_modules.rst (#1210) (#1220)
  * Add link to antsibull-docs docsite (#1198) (#1207)
  * Trim down the docs banners (#1188) (#1204)
  * Merge pull request #1201 from samccann/fix-nit (#1203)
  * Merge pull request #1172 from ansible/pip-compile/devel/dev
  * Merge pull request #1191 from oraNod/fix-ruff-path
  * Update documentation about vars: in roles: since they're no
    longer added to the play's variables (#1181) (#1186)
  * Fix typo (#1175) (#1184)
  * Data Tagging Delayed to 2.18 (#1182) (#1183)
  * [Needs SC vote] Steering Committee: votes on new members to be
    conducted on the forum; change the chairperson election
    procedure (#1085) (#1170)
  * Merge pull request #1174 from
    ansible/dependabot/github_actions/wntrblm/nox-2024.03.02
  * Add Ansible community 9.3.0 porting guide (#1168)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.4:
  * ci: refresh dev dependencies (#1162)
  * Fix problems with example inventory in the intro_patterns doc
    (#1138) (#1158)
  * Update playbooks_templating_now.rst (#1099) (#1156)
  * Merge pull request #1114 from akira6592/fix-ellipsis
  * Merge pull request #1115 from h3xx/fix-syntax-error
  * Merge pull request #1119 from tomkivlin/tomkivlin-patch-1
  * Remove/update incorrect docs building documentation (#1128)
  * steering committee: update members / past members lists (#1143)
    (#1144)
  * Fix core deprecation cycle example to match reality (#1113)
  * Add example around ansible-galaxy command (#1053)
  * ci: refresh dev dependencies (#1131)
  * Improve role argspec documentation (#1126)
  * Update Ansible 9 porting guide. (#1124) (#1125)
  * Merge pull request #1111 from bcoca/fix_typo
  * ci: refresh dev dependencies (#1091)
  * fix version switcher problem` (#1112)
  * Fix doc prompts (#1074) (#1107)
  * nox: run clone-core session in a venv as well (#1055) (#1060)
  * [network] update note about `gather_network_resources` (#1096)
    (#1104)
  * Add network differences explanation (#1051) (#1072)
  * remove outdated ansible/community links (#913)
  * Collection requirements: undocumented-parameter must only be
    used for deprecated parameters or internal parameters (#989)
    (#1100)
  * Extend Ansible 9 lifecycle to November 2024 (#1023) (#1098)
  * Ansible 10 roadmap (#994) (#1097)
  * Add Ansible community 9.2.0 porting guide (#1087)
  * Bump antsibull-docs to 2.7.0. (#1090)
  * community_steering_committee.rst: update with respect to forum
    and collection requirements (#997)
  * ci: refresh dev dependencies (#1049) (#1061)
  * ci: refresh dev dependencies (#1065) (#1077)
  * Remove 2.10 from build (#1046)
* Tue Jan 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.3:
  * convert core docs to use Ansible sphinx theme (#922) (#1067)
  * fix internal links for ansible forum (#1052) (#1062)
  * added `gather_facts/(yes/no)` (#1003) (#1043)
  * [backport][2.16] Add how to request a working group (#912)
    (#1041)
  * collection_requirements: add meta/execution-environments.yml
    (#871) (#1048)
  * collection requirements/steering committee inclusion policy:
    change (#995) (#1047)
  * Proof reading II (#733) (#1039)
  * fix intersphinx  tuples (#880) (#1038)
  * Update task definition in playbook getting started doc (#1029)
    (#1032)
  * Update Arch Linux bugtracker link (#1027) (#1033)
  * ci: refresh dev dependencies (#1022)
  * corrected `test/` folder to `tests/` (#993) (#1017)
  * docs: Document removal of ConfigureRemotingForAnsible.ps1 #794
    (#984) (#1010)
  * Add documentation about --exclude flag (#978) (#1016)
  * Merge pull request #957 from akira6592/fix-exapmle-role-name
    (#1011)
  * Fixed DCO file link (#1005) (#1007)
  * Update windows_setup.rst to fix link (#766) (#1009)
  * Adds note for more details about variable precedence (#930)
  * Document collection naming (#987)
  * Collection requirements: add seealso with link to Collection
    creator path (#976) (#985)
  * Fix argument_specs.yml example (#956) (#988)
  * Add documentation for the custom Jinja2 global function `undef`
    (#953)
  * clone-core.py: allow specifying custom branch and repo (#954)
  * get_bot_user: use correct username in committer email
  * ci pr_labeler: also use the app token for issues (#636)
  * ci pip-compile: remove duplicate environment key (#633)
  * ci: use Github App token to authenticate (#621)
* Sun Jan 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.2:
  * Retroactivelly add a 2.15 porting guide note about handlers
    (#882)
  * bump approved antsibull-docs version to 2.6.0
  * Update windows_winrm.rst (#910) (#951)
  * documentation_contributions: show how to set up a venv and
    remove outdated notes (#911) (#950)
  * handlers notify example indentation fix (#915) (#947)
  * Improve module developing documenation for deprecation and
    linking (#943) (#946)
  * Merge pull request #937 from Andersson007/add_pr_link (#944)
  * Add Ansible community 8.7.0 porting guide (#938)
  * Add 2.14 and 2.15 CVE porting guide to 2.16 (#932)
  * Merge pull request #929 from anweshadas/pr_porting_guide_9.1.0
    (#936)
  * Ansible 9: Follow ansible-core more closely (#856) (#934)
  * README: consistently use `nox -s` over `nox -e` (#923)
* Sun Jan 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.1:
  * nox pip-compile: allow passing --no-upgrade flag (#883) (#920)
  * add nox make session and revamp contribution docs (#707) (#917)
  * installation_guide/intro: update seealso with respect to
    communication (#869) (#908)
  * Update links in plugin documentation (#859) (#907)
  * installation_distros.rst: fix RST hyperlink syntax (#857)
    (#904)
  * developing_collections_path.rst: fix formatting (#842) (#901)
  * Add the mission statement to the community guide (#854) (#902)
  * Fix Edit on GitHub for templated pages, remove superfluous
    template, fix broken link (#865) (#892)
  * add ansible-galaxy to command cheatsheet (#826) (#898)
  * Fix delegate_to details about inheriting vars from 'all' (#825)
    (#897)
  * Update developing_program_flow_modules.rst (#819) (#895)
  * intro_installation: add EE info (#870) (#894)
  * developing_collections_structure.rst: Add EE collection-level
    metadata link to meta directory subsection (#855) (#890)
  * update python versions in installation guide (#836) (#887)
  * add support for Ansible 9 intersphinx links (#878) (#879)
  * Refs #340: Swap old 'CLA' for the DCO (#598) (#875)
  * Add porting guide for CVE-2023-5764 (#866)
  * Update the information on RouterOS network connections. (#841)
    (#863)
  * update galaxy urls for networking docs' (#822) (#862)
  * ci: refresh dev dependencies (#839)
  * ci: refresh dev dependencies (#813)
  * sphinx: remove usage of deprecated notfound-page options (#827)
  * update logic to make it easier to patch for core vs ansible
    release (#849) (#850)
  * downgrade sphinx to 7.1.2 to fix 404 pages
  * add Ansible 9 changelogs (#831) (#848)
  * update backport instructions to match 2.16 (#799) (#846)
  * Set release version to 9 (#832) (#845)
  * Add Ansible community 9.0.0 porting guide (#843) (#844)
  * developing_collections.rst: add collection creator path (#775)
    (#835)
  * EOL 2.13 in release table (#798) (#810)
  * communication.rst: remove inactive security WG (#828) (#833)
  * communication.rst: update Docs WG reference (#785) (#802)
  * communication.rst: update MySQL WG to point to the forum group
    page (#795) (#805)
  * Update the Note for certificate authentication with a TLS 1.3
    connection in windows_winrm.rst  (#757) (#781)
  * [PR #788/2a485247 backport][stable-2.16] Add Ansible community
    8.6.0 porting guide (#791)
  * Porting guide for 9.0.0b1. (#787) (#790)
  * update versioning for 2.16 (#755) (#783)
  * communication.rst: Make WG a top-level section (#750) (#764)
  * intro_installation: pass --include-injected in pipx upgrade
    example (#745) (#768)
  * Replaced the AWX mailing list with the AWX Forum page. (#769)
    (#777)
  * set release version to 2.16 (#756)
* Sun Jan 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.16.0:
  This tag contains a snapshot of the ansible-documentation
  stable-2.16 branch at the time of the ansible-core 2.16.0
  release.
* Tue Dec 12 2023 kastl@b1-systems.de
- Update to version 2.15.8:
  * Retroactivelly add a 2.15 porting guide note about handlers
    (#882)
  * bump approved antsibull-docs version to 2.6.0
  * documentation_contributions: show how to set up a venv and
    remove outdated notes (#911) (#949)
  * Update windows_winrm.rst (#910) (#952)
  * handlers notify example indentation fix (#915) (#948)
  * Merge pull request #937 from Andersson007/add_pr_link (#945)
  * Add Ansible community 8.7.0 porting guide (#938)
  * Add porting guide for CVE-2023-5764 (#933)
  * ci: refresh dev dependencies (#914)
  * README: consistently use `nox -s` over `nox -e` (#923)
* Tue Dec  5 2023 kastl@b1-systems.de
- Update to version 2.15.7:
  * nox pip-compile: allow passing --no-upgrade flag (#883) (#919)
  * add nox make session and revamp contribution docs (#707) (#916)
  * installation_guide/intro: update seealso with respect to
    communication (#869) (#909)
  * Update links in plugin documentation (#859) (#906)
  * installation_distros.rst: fix RST hyperlink syntax (#857)
    (#903)
  * Updated loop docs (#838) (#899)
  * intro_installation: add EE info (#870) (#893)
  * Fix Edit on GitHub for templated pages, remove superfluous
    template, fix broken link (#865) (#891)
  * developing_collections_structure.rst: Add EE collection-level
    metadata link to meta directory subsection (#855) (#889)
  * Add the mission statement to the community guide (#854) (#888)
  * update python versions in installation guide (#836) (#886)
  * add ansible-galaxy to command cheatsheet (#826) (#884)
  * Refs #340: Swap old 'CLA' for the DCO (#598) (#874)
  * ci: refresh dev dependencies (#839) (#861)
  * Add porting guide for CVE-2023-5764 (#867)
  * Update the information on RouterOS network connections. (#841)
    (#864)
  * update backport instructions to match 2.16 (#799) (#847)
  * Fix delegate_to details about inheriting vars from 'all' (#825)
    (#834)
  * communication.rst: Make WG a top-level section (#750) (#806)
  * EOL 2.13 in release table (#798) (#808)
  * ci: refresh dev dependencies (#813) (#814)
  * Update developing_program_flow_modules.rst (#819) (#820)
  * update galaxy urls for networking docs' (#822) (#823)
  * communication.rst: remove inactive security WG (#828) (#830)
  * communication.rst: update MySQL WG to point to the forum group
    page (#795) (#803)
  * communication.rst: update Docs WG reference (#785) (#800)
  * Update the Note for certificate authentication with a TLS 1.3
    connection in windows_winrm.rst  (#757) (#780)
  * [2.15] Add Ansible community 8.6.0 porting guide (#788) (#792)
  * update versioning for 2.16 (#755) (#779)
  * intro_installation: pass --include-injected in pipx upgrade
    example (#745) (#767)
  * Replaced the AWX mailing list with the AWX Forum page. (#769)
    (#776)
* Tue Nov  7 2023 kastl@b1-systems.de
- Update to version 2.15.6:
  * ci: refresh dev dependencies (#770)
  * Fixed equalto test filter (#758) (#759)
  * ci: refresh dev dependencies (#741)
  * nox and README: log PIP_CONSTRAINT value and add Dependency file docs (#730) (#737)
  * [stable-2.15] installation_guide/intro_configuration.rst: improve readability
  * Proof reading (#616) (#729)
  * [PR #668/8d847046 backport] Integrate docs checkers into the noxfile (#727)
  * ci: refresh dev dependencies (#721) (#722)
  * Update JSON queries examples (#690) (#704)
  * communication.rst: other forum-related tweaks (#669) (#698)
  * documentation_contributions: use tests/checkers.py (#706) (#712)
  * Update slicing in inventory pattern (#541) (#693)
  * [stable-2.15] Unify the Sphinx's `conf.py` files (#431) (#627)
  * Update shebang sanity test docs to match test (#677) (#687)
  * Update example using special variables in resuce section of blocks (#671) (#680)
  * ci: refresh dev dependencies (#682)
  * ci: refresh dev dependencies (#672)
  * Use a working exponential backoff example (#607) (#660)
  * Rename tests/sanity.py to tests/checkers.py (#563) (#663)
  * Added delegation info to special vars (#629) (#659)
  * Add forum info to collection maintainer guidelines (#549) (#655)
  * Fix#129 (#201) (#613)
  * Update PowerShell Codeblock (#489) (#603)
  * Changed it's to it is in all .rst files (#491)
  * Clarify that two releases will happen on two separate days, and clarify which one will happen first (#39)
  * pr_labeler: stop adding needs_triage labels to new PRs (#643) (#645)
  * ci: refresh dev dependencies (#638) (#641)
  * [stable-2.15] Add RST spellcheck (#524) (#623)
  * corrected cli for help (#599) (#600)
  * communication.rst: Add a link to the forum group list (#571) (#594)
  * developing_collections_structure.rs: Fix link formatting (#570) (#591)
  * Testing collections guide: add GHA info and link to sample matrix (#569) (#588)
  * issue #560 fix broken url in script (#568) (#585)
  * Document how to bump dependencies (#446) (#614)
  * ci: refresh dev dependencies (#608) (#609)
  * Merge pull request #27 from oraNod/issue-26/add-intro-getting-started (#526)
  * Spellingfix (#494) (#583)
  * communication.rst: fix link (#495) (#580)
  * More info on delegation behaviours (#527) (#582)
  * Replace i.e with that is  (#490) (#565)
  * Fix for : Replace all occurrences of via to with #459 (#479) (#578)
  * issue-457: Update all occurrences of Ansible core to Ansible Core (#471) (#575)
  * communication.rst: Add Release Management WG info (#438) (#574)
  * Update collections_installing.rst (#412) (#573)
  * communication.rst: add forum info (#392) (#572)
  * Integrate `docs/bin/*.py` files into the nox config (#529) (#562)
  * Add Ansible community 8.5.0 porting guide (#556) (#557)
  * fix molecule link in contributor path page (#538) (#551)
  * Add Arch installation instructions in the installation_distros documentation (#522) (#545)
  * ci: refresh dev dependencies (#548)
* Tue Nov  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 2.15.6:
  This tag contains a snapshot of the ansible-documentation
  stable-2.15 branch at the time of the ansible-core 2.15.6
  release.
* Tue Oct 10 2023 kastl@b1-systems.de
- Update to version 2.15.5:
  This tag contains a snapshot of the ansible-documentation
  stable-2.15 branch at the time of the ansible-core 2.15.5
  release.
  * better description of 'short' (#528) (#533)
  * Fix typo (#454) (#517)
  * Add preferred terms list to style guide (#386) (#516)
  * Update automationhub.rst #477 (#485) (#492)
  * pr_labeler: change link to the DAWGs meeting agenda (#497)
    (#504)
  * Bump antsibull-docs to 2.5.0 (#467) (#480)
  * Bump docs build requirements for stable-2.15. (#448)
  * Update 'For instance' to 'For example' (#472) (#475)
  * Prepare Galaxy guides for GalaxyNG (#388) (#474)
  * [stable-2.15] ci: refresh dev dependencies (#447)
  * Add label to 'collections:' keyword. (#434) (#435)
  * Backport/2.15/425 - Change banner for Contributor summit (#430)
  * Update developing_collections_creating.rst (#414) (#416)
  * Removing [] from --tags and --skip-tags (#406) (#421)
  * readthedocs stable-2.15 (#413)
  * added example using the variables (#393) (#394)
  * ci: refresh dev dependencies (#402) (#407)
  * build(deps): bump actions/checkout from 3 to 4 (#372) (#405)
  * Add Ansible community 8.4.0 porting guide (#384) (#385)
* Tue Sep 12 2023 kastl@b1-systems.de
- Update to version 2.15.4:
  This tag contains a snapshot of the ansible-documentation
  stable-2.15 branch at the time of the ansible-core 2.15.4
  release.
* Fri Sep  8 2023 Johannes Kastl <kastl@b1-systems.de>
- new package ansible-documentation
